summaryrefslogtreecommitdiff
path: root/framework/Collections
diff options
context:
space:
mode:
authorxue <>2005-11-20 16:04:33 +0000
committerxue <>2005-11-20 16:04:33 +0000
commitfd8382b03df7243195b38562c8dac7eb45796657 (patch)
tree1e3eb03de7a7d6cf63d491ac7c4a5ef30ae700f4 /framework/Collections
parent97a8c8dbd0c6e107c75c3eaee3633551265e84cb (diff)
Diffstat (limited to 'framework/Collections')
-rw-r--r--framework/Collections/TList.php14
-rw-r--r--framework/Collections/TMap.php2
2 files changed, 8 insertions, 8 deletions
diff --git a/framework/Collections/TMap.php b/framework/Collections/TMap.php
index 7c2333d9..73665136 100644
--- a/framework/Collections/TMap.php
+++ b/framework/Collections/TMap.php
@@ -112,7 +112,7 @@ class TMap extends TComponent implements IteratorAggregate,ArrayAccess
$this->addedItem($key,$value);
}
else
- throw new TInvalidOperationException('map_item_invalid');
+ throw new TInvalidOperationException('map_addition_disallowed');
}
/**
diff --git a/framework/Collections/TList.php b/framework/Collections/TList.php
index 09d9516b..d57e0f62 100644
--- a/framework/Collections/TList.php
+++ b/framework/Collections/TList.php
@@ -88,14 +88,14 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
* This method is exactly the same as {@link offsetGet}.
* @param integer the index of the item
* @return mixed the item at the index
* @throws TIndexOutOfRangeException if the index is out of the range
*/
public function itemAt($index)
{
if(isset($this->_d[$index]))
return $this->_d[$index];
else
- throw new TIndexOutOfRangeException('list_index_invalid',$index);
+ throw new TInvalidDataValueException('list_index_invalid',$index);
}
/**
@@ -120,7 +120,7 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
* will be moved one step towards the end.
* @param integer the speicified position.
* @param mixed new item
* @throws TIndexOutOfRangeException If the index specified exceeds the bound
* @throws TInvalidOperationException If the item is not allowed to be added
*/
public function addAt($index,$item)
@@ -136,7 +136,7 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
$this->addedItem($item);
}
else
- throw new TIndexOutOfRangeException('list_index_invalid',$index);
+ throw new TInvalidDataValueException('list_index_invalid',$index);
}
else
throw new TInvalidOperationException('list_addition_disallowed');
@@ -190,7 +190,7 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
throw new TInvalidOperationException('list_item_unremovable');
}
else
- throw new TIndexOutOfRangeException('list_index_invalid',$index);
+ throw new TInvalidDataValueException('list_index_invalid',$index);
}
/**
@@ -283,14 +283,14 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
* This method is required by the interface ArrayAccess.
* @param integer the offset to retrieve item.
* @return mixed the item at the offset
* @throws TIndexOutOfRangeException if the offset is invalid
*/
public function offsetGet($offset)
{
if(isset($this->_d[$offset]))
return $this->_d[$offset];
else
- throw new TIndexOutOfRangeException('list_index_invalid',$offset);
+ throw new TInvalidDataValueException('list_index_invalid',$offset);
}
/**
@@ -88,14 +88,14 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
* @param integer the index of the item
* @return mixed the item at the index
- * @throws TIndexOutOfRangeException if the index is out of the range
+ * @throws TInvalidDataValueException if the index is out of the range
*/
public function itemAt($index)
@@ -120,7 +120,7 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
* @param integer the speicified position.
* @param mixed new item
- * @throws TIndexOutOfRangeException If the index specified exceeds the bound
+ * @throws TInvalidDataValueException If the index specified exceeds the bound
* @throws TInvalidOperationException If the item is not allowed to be added
*/
@@ -283,14 +283,14 @@ class TList extends TComponent implements IteratorAggregate,ArrayAccess
* @param integer the offset to retrieve item.
* @return mixed the item at the offset
- * @throws TIndexOutOfRangeException if the offset is invalid
+ * @throws TInvalidDataValueException if the offset is invalid
*/
public function offsetGet($offset)